#
# spec file for package cryptsetup (Version 1.0.7)
#
# Copyright (c) 2009 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           cryptsetup
Url:            http://code.google.com/p/cryptsetup/
BuildRequires:  device-mapper-devel e2fsprogs-devel libgcrypt-devel popt-devel
BuildRequires:  libselinux-devel
# hashalot version
%define haver 0.3 
# boot.crypto version
%define bcver 0_200909251440
License:        BSD 3-clause (or similar) ; GPL v2 only ; GPL v2 or later
Group:          System/Base
AutoReqProv:    on
Version:        1.0.7
Release:        6
Summary:        Set Up dm-crypt Based Encrypted Block Devices
Source:         cryptsetup-%{version}.tar.bz2
Source1:        hashalot-%haver.tar.bz2
# http://www.suse.de/~lnussel/boot.crypto.git
Source2:        boot.crypto-%{bcver}.tar.bz2
# use this to create the tarball from svn
Source99:       cryptsetup-mktar
Patch0:         cryptsetup-1.0.7-eofpw.diff
Patch10:        hashalot-fixes.diff
Patch11:        hashalot-libgcrypt.diff
Patch12:        hashalot-ctrl-d.diff
Patch13:        hashalot-timeout.diff
Patch14:        hashalot-manpage.diff
Patch15:        bug-476290_hashalot-hashlen.diff
Patch16:        hashalot-glibc210.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Provides:       aaa_base:/etc/init.d/boot.crypto
Obsoletes:      util-linux-crypto <= 2.12r
# we need losetup
Requires:       util-linux
PreReq:         %fillup_prereq %insserv_prereq

%description
cryptsetup is used to conveniently set up dm-crypt based device-mapper
targets. It allows to set up targets to read cryptoloop compatible
volumes as well as LUKS formatted ones. The package additionally
includes support for automatically setting up encrypted volumes at boot
time via the config file /etc/crypttab.



Authors:
--------
    Clemens Fruhwirth <clemens@endorphin.org>
    Christophe Saout <christophe@saout.de>
    Ben Slusky <sluskyb@paranoiacs.org>

%package -n libcryptsetup0
License:        BSD 3-clause (or similar) ; GPL v2 only ; GPL v2 or later
Summary:        Set Up dm-crypt Based Encrypted Block Devices
Group:          System/Base

%description  -n libcryptsetup0
cryptsetup is used to conveniently set up dm-crypt based device-mapper
targets. It allows to set up targets to read cryptoloop compatible
volumes as well as LUKS formatted ones. The package additionally
includes support for automatically setting up encrypted volumes at boot
time via the config file /etc/crypttab.



Authors:
--------
    Clemens Fruhwirth <clemens@endorphin.org>
    Christophe Saout <christophe@saout.de>
    Ben Slusky <sluskyb@paranoiacs.org>

%package -n libcryptsetup-devel
License:        BSD 3-clause (or similar) ; GPL v2 only ; GPL v2 or later
Summary:        Set Up dm-crypt Based Encrypted Block Devices
Group:          Development/Libraries/C and C++
# cryptsetup-devel last used 11.1
Provides:       cryptsetup-devel = %{version}
Obsoletes:      cryptsetup-devel < %{version}
Requires:       libcryptsetup0 = %{version}
Requires:       device-mapper-devel libgcrypt-devel libgpg-error-devel e2fsprogs-devel glibc-devel

%description  -n libcryptsetup-devel
cryptsetup is used to conveniently set up dm-crypt based device-mapper
targets. It allows to set up targets to read cryptoloop compatible
volumes as well as LUKS formatted ones. The package additionally
includes support for automatically setting up encrypted volumes at boot
time via the config file /etc/crypttab.



Authors:
--------
    Clemens Fruhwirth <clemens@endorphin.org>
    Christophe Saout <christophe@saout.de>
    Ben Slusky <sluskyb@paranoiacs.org>

%prep
%setup -q -b 1 -b 2
%patch0 -p1
pushd ../hashalot-%haver
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
popd

%build
# cryptsetup build
%{?suse_update_config:%{suse_update_config}}
autoreconf -f -i
CFLAGS="$RPM_OPT_FLAGS" ./configure --prefix=%_prefix --mandir=%_mandir \
				    --libdir=/%_lib \
				    --bindir=/sbin --sbindir=/sbin \
				    --disable-static --enable-shared \
				    --enable-selinux
make
#
# hashalot build
pushd ../hashalot-%haver
autoreconf -f -i
%{?suse_update_config:%{suse_update_config}}
CFLAGS="$RPM_OPT_FLAGS" ./configure --prefix=%_prefix --sbindir=/sbin --mandir=%_mandir 
make
popd

%install
make install DESTDIR=$RPM_BUILD_ROOT
# move devel .so link to %{libdir}
rm -f $RPM_BUILD_ROOT/%{_lib}/libcryptsetup.so
mkdir -p $RPM_BUILD_ROOT%{_libdir}
ln -s /%{_lib}/libcryptsetup.so.0.0.0 $RPM_BUILD_ROOT%{_libdir}/libcryptsetup.so
# don't want this file in /lib (FHS compat check), and can't move it to /usr/lib
rm -f $RPM_BUILD_ROOT/%_lib/*.la
#
# hashalot install
pushd ../hashalot-%haver
make install DESTDIR=$RPM_BUILD_ROOT
popd
# remove unwanted symlinks
rm -f $RPM_BUILD_ROOT/sbin/{rmd160,sha256,sha384,sha512}
#
# boot.crypto
make -C ../boot.crypto-* install DESTDIR=$RPM_BUILD_ROOT
ln -s /etc/init.d/boot.crypto $RPM_BUILD_ROOT/sbin/rccrypto
#
%find_lang %name --all-name

%pre
# hack to catch update case from aaa_base/util-linux-crypto
if [ -f /etc/init.d/boot.d/S??boot.crypto ]; then
	touch /var/run/cryptsetup.boot.crypto.enabled
fi

%post
[ -x /sbin/mkinitrd_setup ] && mkinitrd_setup
%{fillup_and_insserv boot.crypto}
if [ -e /var/run/cryptsetup.boot.crypto.enabled ]; then
	rm -f /var/run/cryptsetup.boot.crypto.enabled
	%{fillup_and_insserv -fY boot.crypto}
fi
%{fillup_and_insserv boot.crypto-early}

%postun
[ -x /sbin/mkinitrd_setup ] && mkinitrd_setup
%{insserv_cleanup}

%post -n libcryptsetup0
/sbin/ldconfig

%postun -n libcryptsetup0
/sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%files -f %name.lang
%defattr(-,root,root)
%ghost %verify(not md5 size mtime) %config(noreplace,missingok) /etc/crypttab
%ghost %verify(not md5 size mtime) %config(noreplace,missingok) /etc/cryptotab
/etc/init.d/boot.crypto
/etc/init.d/boot.crypto-early
%dir /lib/mkinitrd
%dir /lib/mkinitrd/scripts
/lib/mkinitrd/scripts/setup-luks.sh
/lib/mkinitrd/scripts/boot-luks.sh
/sbin/cryptsetup
/sbin/hashalot
/sbin/rccrypto
%_mandir/man1/hashalot.1.gz
%_mandir/man8/cryptsetup.8.gz
%_mandir/man5/crypttab.5.gz
%_mandir/man5/cryptotab.5.gz
/lib/cryptsetup

%files -n libcryptsetup0
%defattr(-,root,root)
/%_lib/libcryptsetup.so.0
/%_lib/libcryptsetup.so.0.0.0

%files -n libcryptsetup-devel
%defattr(-,root,root)
%_includedir/libcryptsetup.h
%{_libdir}/libcryptsetup.so

%changelog
